============================
 Invenio-Formatter v1.0.0a2
============================

Invenio-Formatter v1.0.0a2 was released on April 22, 2016.

About
-----

Jinja utilities for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-formatter==1.0.0a2

Documentation
-------------

   http://pythonhosted.org/invenio-formatter/

Happy hacking and thanks for flying Invenio-Formatter.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-formatter
|   URL: http://invenio-software.org
